**********************
``matplotlib.widgets``
**********************

.. currentmodule:: matplotlib.widgets

.. automodule:: matplotlib.widgets
   :no-members:
   :no-undoc-members:


Widget classes
==============

.. inheritance-diagram:: matplotlib.widgets.Widget
   :parts: 1
   :private-bases:
   :include-subclasses:

.. autosummary::
   :toctree: _as_gen
   :template: autosummary.rst
   :nosignatures:

   Widget
   AxesWidget
   Cursor
   MultiCursor
   Button
   _Buttons
   CheckButtons
   RadioButtons
   SliderBase
   Slider
   RangeSlider
   TextBox
   _SelectorWidget
   RectangleSelector
   EllipseSelector
   Lasso
   LassoSelector
   PolygonSelector
   SpanSelector
   SubplotTool

Helper classes
==============

.. autosummary::
   :toctree: _as_gen
   :nosignatures:

   LockDraw
   ToolHandles
   ToolLineHandles
